Package: TDbasedUFE
Type: Package
Title: Tensor Decomposition Based Unsupervised Feature Extraction
Version: 1.12.0
Authors@R: 
    person("Y-h.", "Taguchi", ,
    "tag@granular.com", role = c("aut", "cre"),
    comment = c(ORCID  = "0000-0003-0867-8986"))
Description: 
    This is a comprehensive package to perform
    Tensor decomposition based unsupervised feature extraction.
    It can perform unsupervised feature extraction.
    It uses tensor decomposition.
    It is  applicable to gene expression, DNA methylation, and 
    histone modification etc.
    It can perform multiomics analysis.
    It is also potentially applicable to single cell omics data sets.
biocViews: GeneExpression, FeatureExtraction, MethylationArray,
        SingleCell
License: GPL-3
Encoding: UTF-8
URL: https://github.com/tagtag/TDbasedUFE
BugReports: https://github.com/tagtag/TDbasedUFE/issues
Imports: GenomicRanges, rTensor, readr, methods, MOFAdata, tximport,
        tximportData, graphics, stats, utils, shiny
RoxygenNote: 7.2.3
Roxygen: list(markdown = TRUE)
Suggests: BiocStyle, knitr, rmarkdown, testthat (>= 3.0.0)
VignetteBuilder: knitr
Config/testthat/edition: 3
git_url: https://git.bioconductor.org/packages/TDbasedUFE
git_branch: RELEASE_3_23
git_last_commit: 1763056
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 23:43:38 UTC; biocbuild
Author: Y-h. Taguchi [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-0867-8986>)
Maintainer: Y-h. Taguchi <tag@granular.com>
Built: R 4.6.0; ; 2026-04-29 05:03:31 UTC; unix
