# Generated by roxygen2: do not edit by hand

export(PrepareSummarizedExperimentTensor)
export(PrepareSummarizedExperimentTensorSquare)
export(computeHosvd)
export(computeHosvdSqure)
export(convertSquare)
export(selectFeature)
export(selectFeatureSquare)
export(selectSingularValueVectorLarge)
export(selectSingularValueVectorSmall)
export(tableFeatures)
export(tableFeaturesSquare)
import(MOFAdata)
import(methods)
import(readr)
import(tximport)
import(tximportData)
importFrom(GenomicRanges,GRanges)
importFrom(graphics,abline)
importFrom(graphics,arrows)
importFrom(graphics,boxplot)
importFrom(graphics,hist)
importFrom(graphics,par)
importFrom(methods,new)
importFrom(rTensor,as.tensor)
importFrom(rTensor,hosvd)
importFrom(shiny,actionButton)
importFrom(shiny,fluidPage)
importFrom(shiny,mainPanel)
importFrom(shiny,observeEvent)
importFrom(shiny,plotOutput)
importFrom(shiny,renderPlot)
importFrom(shiny,runApp)
importFrom(shiny,shinyApp)
importFrom(shiny,sidebarLayout)
importFrom(shiny,sidebarPanel)
importFrom(shiny,stopApp)
importFrom(stats,optim)
importFrom(stats,p.adjust)
importFrom(stats,pchisq)
importFrom(utils,menu)
