
<!-- README.md is generated from README.Rmd. Please edit that file -->

# TDbasedUFE

<!-- badges: start -->
<!-- badges: end -->

The goal of TDbasedUFE is to …

## Installation

You can install the latest release of TDbasedUFE from
[GitHub](https://github.com/) with:

``` r
# install.packages("devtools")
devtools::install_github("tagtag/TDbasedUFE@v0.1.0")
```

You can install the development version of TDbasedUFE from
[GitHub](https://github.com/) with:

``` r
# install.packages("devtools")
devtools::install_github("tagtag/TDbasedUFE",build_vignettes = TRUE)
```

or if it does not work, try

``` r
# install.packages("devtools")
devtools::install_github("tagtag/TDbasedUFE")
```

# TDbasedUFE

**Tensor decomposition based unsupervised feature extraction**

## Manuscript

The theoretical back ground of this package was described in the
following book:

***“Unsupervised Feature Extraction Applied to Bioinformatics: A PCA
Based and TD Based Approach”*** by Y-h. Taguchi

Please cite the book as:

``` latex
@book{Taguchi2020,
  doi = {10.1007/978-3-030-22456-1},
  url = {https://doi.org/10.1007/978-3-030-22456-1},
  year = {2020},
  publisher = {Springer International Publishing},
  author = {Y-H. Taguchi},
  title = {Unsupervised Feature Extraction Applied to Bioinformatics}
}
```

[\[DOI\]](https://doi.org/10.1007/978-3-030-22456-1)

## Vignettes

How to use it

vignette(“QuickStart”)

For more theoretical background

vignette(“TDbasedUFE”)
