#' @keywords internal
"_PACKAGE"

## usethis namespace: start
#' @import methods
#' @import readr
#' @import MOFAdata
#' @import tximport
#' @import tximportData
#' @importFrom shiny fluidPage sidebarLayout  sidebarPanel actionButton 
#' mainPanel plotOutput observeEvent runApp shinyApp stopApp renderPlot
#' @importFrom methods new
#' @importFrom GenomicRanges GRanges
#' @importFrom rTensor hosvd as.tensor
#' @importFrom stats pchisq p.adjust optim
#' @importFrom graphics hist par arrows boxplot abline
#' @importFrom utils menu
#'
## usethis namespace: end
NULL
